@@ -147,7 +147,7 @@ class ONNXRTAdaptor(Adaptor):
         tmp_model.model = quantizer.model.model
         self.quantize_config = quantize_config # update so other methods can know current configs
 
-        self._dump_model_op_stastics(tmp_model)
+        self._dump_model_op_stats(tmp_model)
         return tmp_model
 
     def _generate_qconfig(self, model, tune_cfg, quantize_params):
@@ -232,7 +232,7 @@ class ONNXRTAdaptor(Adaptor):
             quantize_params = None
         return quantize_params, tune_cfg
 
-    def _dump_model_op_stastics(self, model):
+    def _dump_model_op_stats(self, model):
         fp32_op_list = self.query_handler.get_op_types_by_precision( # pylint: disable=no-member
             precision='int8')
 
@@ -617,17 +617,22 @@ class ONNXRTAdaptor(Adaptor):
                 if not isinstance(labels, list):
                     labels = [labels]
                 if len_inputs == 1:
-                    ort_inputs.update({inputs_names[0]: inputs})
+                    ort_inputs.update(
+                        inputs if isinstance(inputs, dict) else {inputs_names[0]: inputs}
+                    )
                 else:
                     assert len_inputs == len(inputs), \
-                        'number of input tensors must align with graph inputs'  
+                        'number of input tensors must align with graph inputs'
 
-                    for i in range(len_inputs):
-                        # in case dataloader contains non-array input
-                        if not isinstance(inputs[i], np.ndarray):
-                            ort_inputs.update({inputs_names[i]: np.array(inputs[i])})
-                        else:
-                            ort_inputs.update({inputs_names[i]: inputs[i]})   
+                    if isinstance(inputs, dict):  # pragma: no cover
+                        ort_inputs.update(inputs)
+                    else:
+                        for i in range(len_inputs):
+                            # in case dataloader contains non-array input
+                            if not isinstance(inputs[i], np.ndarray):
+                                ort_inputs.update({inputs_names[i]: np.array(inputs[i])})
+                            else:
+                                ort_inputs.update({inputs_names[i]: inputs[i]})
 
                 if measurer is not None:
                     measurer.start()
@@ -731,7 +736,7 @@ class ONNXRTQuery(QueryBackendCapability):
                 raise ValueError("Please check if the format of {} follows Neural Compressor yaml schema.".
                                  format(self.cfg))
 
-    def _get_specified_version_cfg(self, data):
+    def _get_specified_version_cfg(self, data): # pragma: no cover
         """Get the configuration for the current runtime.
         If there's no matched configuration in the input yaml, we'll
         use the `default` field of yaml.
@@ -744,10 +749,10 @@ class ONNXRTQuery(QueryBackendCapability):
         """
         default_config = None
         for sub_data in data:
-            if sub_data['version']['name'] == self.version:
+            if self.version in sub_data['version']['name']:
                 return sub_data
 
-            if sub_data['version']['name'] == 'default':
+            if 'default' in sub_data['version']['name']:
                 default_config = sub_data
 
         return default_config
