@@ -45,7 +45,7 @@ from .graph_rewriter.int8.meta_op_optimizer import MetaInfoChangingMemOpOptimize
 from .graph_rewriter.int8.rnn_convert import QuantizedRNNConverter
 
 
-TF_SUPPORTED_MAX_VERSION = '2.6.0'
+TF_SUPPORTED_MAX_VERSION = '2.6.2'
 TF_SUPPORTED_MIN_VERSION = '1.14.0'
 
 logger = logging.getLogger()
@@ -103,7 +103,7 @@ class GraphConverterWithoutCalib:
             if IsMklEnabled() and (TF_SUPPORTED_MIN_VERSION <= tf.version.VERSION):
                 is_supported_version = True
 
-            if tf.version.VERSION == '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') == '1':
+            if tf.version.VERSION.find('2.6.') != -1 and os.getenv('TF_ENABLE_ONEDNN_OPTS') == '1':
                 is_supported_version = True
         except Exception as e:
             raise ValueError(e)
@@ -120,9 +120,9 @@ class GraphConverterWithoutCalib:
                 logger.warning("Please set environment variable TF_ENABLE_MKL_NATIVE_FORMAT=0 "
                                "when Tensorflow 2.5.0 installed.")
 
-            if tf.version.VERSION == '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') != '1':
+            if tf.version.VERSION.find('2.6.') != -1 and os.getenv('TF_ENABLE_ONEDNN_OPTS') != '1':
                 logger.warning("Please set environment variable TF_ENABLE_ONEDNN_OPTS=1 "
-                               "when Tensorflow 2.6.0 installed.")
+                               "when Tensorflow 2.6.x installed.")
 
             if not is_supported_version:
                 raise ValueError(
