@@ -22,7 +22,7 @@ import subprocess
 import signal
 import psutil
 from ..adaptor import FRAMEWORKS
-from ..objective import OBJECTIVES
+from ..objective import MultiObjective
 from ..conf.config import Benchmark_Conf
 from ..conf.dotdict import DotDict
 from ..utils import logger
@@ -84,6 +84,7 @@ class Benchmark(object):
         self.framework = None
         self._model = None
         self._b_dataloader = None
+        self._metric = None
         self._results = {}
         if isinstance(conf_fname_or_obj, Benchmark_Conf):
             self.conf = conf_fname_or_obj
@@ -108,6 +109,8 @@ class Benchmark(object):
         else:
             return self.config_instance()
 
+    fit = __call__
+
     def config_instance(self):
         raw_cmd = sys.executable + ' ' + ' '.join(sys.argv)
         multi_instance_cmd = ''
@@ -183,7 +186,8 @@ class Benchmark(object):
         if framework == 'engine':
             framework_specific_info.update(
                  {"workspace_path": cfg.tuning.workspace.path, \
-                  "b_dataloader": self._b_dataloader})
+                  "b_dataloader": self._b_dataloader, \
+                  'q_dtype': cfg.quantization.dtype})
 
         assert isinstance(self._model, BaseModel), 'need set neural_compressor Model for quantization....'
 
@@ -196,8 +200,8 @@ class Benchmark(object):
         iteration = -1 if deep_get(cfg, 'evaluation.{}.iteration'.format(mode)) is None \
             else deep_get(cfg, 'evaluation.{}.iteration'.format(mode))
 
-
-        metric =  deep_get(cfg, 'evaluation.{}.metric'.format(mode))
+        metric = self._metric if self._metric else \
+                    deep_get(cfg, 'evaluation.{}.metric'.format(mode))
         b_postprocess_cfg = deep_get(cfg, 'evaluation.{}.postprocess'.format(mode))
 
         if self._b_dataloader is None:
@@ -220,11 +224,15 @@ class Benchmark(object):
                                       b_postprocess_cfg,
                                       iteration=iteration)
 
-        objective = cfg.tuning.objective.lower()
-        self.objective = OBJECTIVES[objective](cfg.tuning.accuracy_criterion, \
-                                               is_measure=True)
+        objectives = [i.lower() for i in cfg.tuning.multi_objective.objective]
+        assert len(objectives) == 1, 'benchmark supports one objective at a time'
+        self.multi_objective = MultiObjective(objectives,
+                                              cfg.tuning.accuracy_criterion,
+                                              cfg.tuning.multi_objective.weight,
+                                              is_measure=True)
 
-        val = self.objective.evaluate(b_func, self._model)
+
+        val = self.multi_objective.evaluate(b_func, self._model)
         # measurer contain info not only performance(eg, memory, model_size)
         # also measurer have result list among steps
         acc, _ = val
@@ -232,13 +240,13 @@ class Benchmark(object):
         warmup =  0 if deep_get(cfg, 'evaluation.{}.warmup'.format(mode)) is None \
             else deep_get(cfg, 'evaluation.{}.warmup'.format(mode))
 
-        if len(self.objective.measurer.result_list()) < warmup:
-            if len(self.objective.measurer.result_list()) > 1 and warmup != 0:
+        if len(self.multi_objective.objectives[0].result_list()) < warmup:
+            if len(self.multi_objective.objectives[0].result_list()) > 1 and warmup != 0:
                 warmup = 1
             else:
                 warmup = 0
 
-        result_list = self.objective.measurer.result_list()[warmup:]
+        result_list = self.multi_objective.objectives[0].result_list()[warmup:]
         latency = np.array(result_list).mean() / batch_size
         self._results[mode] = acc, batch_size, result_list
 
@@ -343,7 +351,8 @@ class Benchmark(object):
            this api. The metric class should take the outputs of the model or 
            postprocess(if have) as inputs, neural_compressor built-in metric always take 
            (predictions, labels) as inputs for update,
-           and user_metric.metric_cls should be sub_class of neural_compressor.metric.BaseMetric.
+           and user_metric.metric_cls should be sub_class of neural_compressor.metric.BaseMetric
+           or user defined metric object
 
         Args:
             user_metric(neural_compressor.experimental.common.Metric):
@@ -353,17 +362,21 @@ class Benchmark(object):
                 specific frameworks and initialized.
                                               
         """
-        assert isinstance(user_metric, NCMetric), \
-            'please initialize a neural_compressor.experimental.common.Metric and set....'
-
-        metric_cfg = {user_metric.name : {**user_metric.kwargs}}
         if deep_get(self.conf.usr_cfg, "evaluation.accuracy.metric"):
             logger.warning("Override the value of `metric` field defined in yaml file" \
                            " as user defines the value of `metric` attribute by code.")
-        deep_set(self.conf.usr_cfg, "evaluation.accuracy.metric", metric_cfg)
-        self.conf.usr_cfg = DotDict(self.conf.usr_cfg)
-        metrics = METRICS(self.framework)
-        metrics.register(user_metric.name, user_metric.metric_cls)
+ 
+        if isinstance(user_metric, NCMetric):
+            metric_cfg = {user_metric.name : {**user_metric.kwargs}}
+            deep_set(self.conf.usr_cfg, "evaluation.accuracy.metric", metric_cfg)
+            self.conf.usr_cfg = DotDict(self.conf.usr_cfg)
+            metrics = METRICS(self.framework)
+            metrics.register(user_metric.name, user_metric.metric_cls)
+        else:
+            for i in ['reset', 'update', 'result']:
+                assert hasattr(user_metric, i), 'Please realise {} function' \
+                                                'in user defined metric'.format(i)
+            self._metric = user_metric
 
     @property
     def postprocess(self, user_postprocess):
