@@ -39,6 +39,7 @@ class Component(object):
         self._train_distributed = False
         self._evaluation_distributed = False
         self.adaptor = None
+        self._metric = None
         self.hooks = {
             'pre_epoch_begin': self.pre_epoch_begin,
             'post_epoch_end': self.post_epoch_end,
@@ -85,8 +86,9 @@ class Component(object):
         framework_specific_info = {'device': self.cfg.device,
                                    'random_seed': self.cfg.tuning.random_seed,
                                    'workspace_path': self.cfg.tuning.workspace.path,
-                                   'approach': self.cfg.quantization.approach,
                                    'q_dataloader': None}
+        if self.cfg.quantization.approach is not None:
+            framework_specific_info['approach'] = self.cfg.quantization.approach
 
         if self.framework == 'tensorflow' or self.framework == 'tensorflow_itex':
             framework_specific_info.update(
@@ -121,10 +123,11 @@ class Component(object):
                                                     self.cfg.train,
                                                     hooks=self.hooks)
         if self._eval_func is None:
+            metric = self._metric if self._metric else self.cfg.evaluation.accuracy.metric
             self._eval_func = create_eval_func(self.framework,
                                                self._eval_dataloader,
                                                self.adaptor,
-                                               self.cfg.evaluation.accuracy.metric,
+                                               metric,
                                                self.cfg.evaluation.accuracy.postprocess,
                                                fp32_baseline = False)
         # register Quantization Aware Training hooks
@@ -204,7 +207,8 @@ class Component(object):
     def register_hook(self, scope, hook, input_args=None, input_kwargs=None):
         """ register hook for component. input_args and input_kwargs are reserved for user
             registered hooks."""
-        self.hooks_dict[scope].append(hook)
+        if hook not in self.hooks_dict[scope]:
+            self.hooks_dict[scope].append(hook)
 
     def __call__(self):
         self.pre_process()
@@ -367,4 +371,4 @@ class Component(object):
             self._model.output_tensor_names = self.cfg.model.outputs
             self._model.input_tensor_names = self.cfg.model.inputs
             self._model.workspace_path = self.cfg.tuning.workspace.path
-            
\ No newline at end of file
+            
