@@ -13,15 +13,29 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Data shape class."""
+from typing import Any, Dict, List, Optional, Union
+
 from neural_compressor.ux.utils.json_serializer import JsonSerializer
 
 
 class Shape(JsonSerializer):
     """Data shape definition."""
 
-    def __init__(self, shape: str = "", trusted: bool = False) -> None:
+    def __init__(self, shape: Optional[str] = "", trusted: bool = False) -> None:
         """Object construction."""
         super().__init__()
 
         self.shape = shape
         self.trusted = trusted
+
+    def serialize(
+        self,
+        serialization_type: str = "default",
+    ) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
+        """Serialize Shape class to dict."""
+        result = {}
+        for key, value in self.__dict__.items():
+            if key in self._skip:
+                continue
+            result.update({key: value})
+        return result
