@@ -121,11 +121,23 @@ class TestDistillation(unittest.TestCase):
         from neural_compressor.conf.config import Distillation_Conf
         conf = Distillation_Conf('fake.yaml')
         distiller = Distillation(conf)
-        distiller = Distillation('fake.yaml')
-        distiller.student_model = common.Model(self.student_model)
-        distiller.teacher_model = common.Model(self.teacher_model)
+        distiller = Distillation()
+
+        from neural_compressor import conf
+        conf.model.framework = 'pytorch'
+        conf.distillation.train.end_epoch = 3
+        conf.distillation.train.iteration = 10
+        conf.distillation.train.optimizer = {
+            'SGD': {'learning_rate': 0.001, 'momentum': 0.1, 'nesterov': True, 'weight_decay': 0.001}}
+        conf.distillation.train.dataloader.batch_size = 30
+        conf.distillation.train.dataloader.dataset = {'dummy': {'shape': [128, 3, 224, 224], 'label': True}}
+        conf.evaluation.accuracy.dataloader.batch_size = 30
+        conf.evaluation.accuracy.dataloader.dataset = {'dummy': {'shape': [128, 3, 224, 224], 'label': True}}
+        distiller = Distillation(conf)
+        distiller.student_model = self.student_model
+        distiller.teacher_model = self.teacher_model
         print('student model: {}'.format(distiller.student_model))
-        _ = distiller()
+        _ = distiller.fit()
 
     def test_distillation_external(self):
         import tensorflow as tf
@@ -177,7 +189,7 @@ class TestDistillation(unittest.TestCase):
         distiller.train_func = training_func_for_nc
         distiller.eval_dataloader = dummy_dataloader
         distiller.train_dataloader = dummy_dataloader
-        _ = distiller()
+        _ = distiller.fit()
         distiller.train_func = create_train_func(
                                                 distiller.framework, \
                                                 distiller.train_dataloader, \
@@ -192,10 +204,10 @@ class TestDistillation(unittest.TestCase):
         conf = Distillation_Conf('fake_1.yaml')
         distiller = Distillation(conf)
         distiller = Distillation('fake_1.yaml')
-        distiller.student_model = common.Model(self.student_model_tf)
-        distiller.teacher_model = common.Model(self.teacher_model_tf)
+        distiller.student_model = self.student_model_tf
+        distiller.teacher_model = self.teacher_model_tf
         print('student model: {}'.format(distiller.student_model))
-        _ = distiller()
+        _ = distiller.fit()
 
 if __name__ == "__main__":
     unittest.main()
